@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (C) 2002-2013, OFFIS e.V.
+ *  Copyright (C) 2002-2014, OFFIS e.V.
  *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
@@ -346,20 +346,8 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--enable-new-vr"))
-      {
-          dcmEnableUnknownVRGeneration.set(OFTrue);
-          dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-          dcmEnableOtherFloatStringVRGeneration.set(OFTrue);
-          dcmEnableOtherDoubleStringVRGeneration.set(OFTrue);
-      }
-      if (cmd.findOption("--disable-new-vr"))
-      {
-          dcmEnableUnknownVRGeneration.set(OFFalse);
-          dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-          dcmEnableOtherFloatStringVRGeneration.set(OFFalse);
-          dcmEnableOtherDoubleStringVRGeneration.set(OFFalse);
-      }
+      if (cmd.findOption("--enable-new-vr")) dcmEnableGenerationOfNewVRs();
+      if (cmd.findOption("--disable-new-vr")) dcmDisableGenerationOfNewVRs();
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
